@@ -18,12 +18,10 @@ import os
 from pysisu import PySisu
 
 API_KEY = os.environ.get('SISU_API_KEY')
-ANALYSIS_ID = 165661
+ANALYSIS_ID = 15245
 
 sisu = PySisu(API_KEY)
-table = sisu.get_results(
-    analysis_id=ANALYSIS_ID, params={"top_drivers": "False", "limit": 10})
+table = sisu.get_results(ANALYSIS_ID, {"top_drivers": "True"})
 print(','.join([x.column_name for x in table.header]))
-print(','.join([str(x.column_type) for x in table.header]))
 for row in table.rows:
     print(row)
