@@ -58,6 +58,8 @@ class PySisu:
 
         MUTATES: result
         '''
+        if not result.pagination_hints.has_more:
+            return result
         if params.get('limit', MAX_LIMIT) >= MAX_LIMIT:
             params['limit'] = MAX_LIMIT
 
@@ -85,7 +87,6 @@ class PySisu:
         path = ['api/v1/analyses/', str(analysis_id), 'runs/latest']
 
         url_path = build_url(self._url,  pathjoin(*path), params)
-        print(url_path)
 
         headers = headers = {"Authorization": self._api_key}
 
